Tanks in Series
===============

N-CSTR (Continuously Stirred Tank Reactor) or Tanks in Series model

.. automodule:: rtdpy.ncstr
   :members:
   :inherited-members:
   :show-inheritance:
   :undoc-members:
